# mypy-boto3-quicksight<a id="mypy-boto3-quicksight"></a>

[![PyPI - mypy-boto3-quicksight](https://img.shields.io/pypi/v/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-quicksight?color=blue)](https://pypistats.org/packages/mypy-boto3-quicksight)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.QuickSight 1.17.69](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/quicksight.html#QuickSight)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.12.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-quicksight docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-quicksight](#mypy-boto3-quicksight)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `QuickSight` service.

```bash
python -m pip install boto3-stubs[quicksight]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`

Both type checking and auto-complete should work for `QuickSight` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`

Both type checking and auto-complete should work for `QuickSight` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`
- Run `mypy` as usual

Type checking should work for `QuickSight` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `QuickSight` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`QuickSightClient` provides annotations for `boto3.client("quicksight")`.

```python
import boto3

from mypy_boto3_quicksight import QuickSightClient

client: QuickSightClient = boto3.client("quicksight")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: QuickSightClient = session.client("quicksight")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_quicksight.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_quicksight import QuickSightClient
from mypy_boto3_quicksight.paginator import (
    ListAnalysesPaginator,
    ListDashboardVersionsPaginator,
    ListDashboardsPaginator,
    ListDataSetsPaginator,
    ListDataSourcesPaginator,
    ListIngestionsPaginator,
    ListNamespacesPaginator,
    ListTemplateAliasesPaginator,
    ListTemplateVersionsPaginator,
    ListTemplatesPaginator,
    ListThemeVersionsPaginator,
    ListThemesPaginator,
    SearchAnalysesPaginator,
    SearchDashboardsPaginator,
)

client: QuickSightClient = boto3.client("quicksight")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_analyses_paginator: ListAnalysesPaginator = client.get_paginator("list_analyses")
list_dashboard_versions_paginator: ListDashboardVersionsPaginator = client.get_paginator("list_dashboard_versions")
list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
list_data_sets_paginator: ListDataSetsPaginator = client.get_paginator("list_data_sets")
list_data_sources_paginator: ListDataSourcesPaginator = client.get_paginator("list_data_sources")
list_ingestions_paginator: ListIngestionsPaginator = client.get_paginator("list_ingestions")
list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
list_template_aliases_paginator: ListTemplateAliasesPaginator = client.get_paginator("list_template_aliases")
list_template_versions_paginator: ListTemplateVersionsPaginator = client.get_paginator("list_template_versions")
list_templates_paginator: ListTemplatesPaginator = client.get_paginator("list_templates")
list_theme_versions_paginator: ListThemeVersionsPaginator = client.get_paginator("list_theme_versions")
list_themes_paginator: ListThemesPaginator = client.get_paginator("list_themes")
search_analyses_paginator: SearchAnalysesPaginator = client.get_paginator("search_analyses")
search_dashboards_paginator: SearchDashboardsPaginator = client.get_paginator("search_dashboards")
```

### Literals<a id="literals"></a>

`mypy_boto3_quicksight.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_quicksight.literals import (
    AnalysisErrorType,
    AnalysisFilterAttribute,
    AssignmentStatus,
    ColumnDataType,
    DashboardBehavior,
    DashboardErrorType,
    DashboardFilterAttribute,
    DashboardUIState,
    DataSetImportMode,
    DataSourceErrorInfoType,
    DataSourceType,
    Edition,
    EmbeddingIdentityType,
    FileFormat,
    FilterOperator,
    GeoSpatialCountryCode,
    GeoSpatialDataRole,
    IdentityStore,
    IdentityType,
    IngestionErrorType,
    IngestionRequestSource,
    IngestionRequestType,
    IngestionStatus,
    InputColumnDataType,
    JoinType,
    ListAnalysesPaginatorName,
    ListDashboardVersionsPaginatorName,
    ListDashboardsPaginatorName,
    ListDataSetsPaginatorName,
    ListDataSourcesPaginatorName,
    ListIngestionsPaginatorName,
    ListNamespacesPaginatorName,
    ListTemplateAliasesPaginatorName,
    ListTemplateVersionsPaginatorName,
    ListTemplatesPaginatorName,
    ListThemeVersionsPaginatorName,
    ListThemesPaginatorName,
    NamespaceErrorType,
    NamespaceStatus,
    ResourceStatus,
    RowLevelPermissionPolicy,
    SearchAnalysesPaginatorName,
    SearchDashboardsPaginatorName,
    TemplateErrorType,
    TextQualifier,
    ThemeErrorType,
    ThemeType,
    UserRole,
)

def check_value(value: AnalysisErrorType) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_quicksight.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_quicksight.type_defs import (
    AccountCustomizationTypeDef,
    AccountSettingsTypeDef,
    ActiveIAMPolicyAssignmentTypeDef,
    AdHocFilteringOptionTypeDef,
    AmazonElasticsearchParametersTypeDef,
    AnalysisErrorTypeDef,
    AnalysisSearchFilterTypeDef,
    AnalysisSourceEntityTypeDef,
    AnalysisSourceTemplateTypeDef,
    AnalysisSummaryTypeDef,
    AnalysisTypeDef,
    AthenaParametersTypeDef,
    AuroraParametersTypeDef,
    AuroraPostgreSqlParametersTypeDef,
    AwsIotAnalyticsParametersTypeDef,
    BorderStyleTypeDef,
    CalculatedColumnTypeDef,
    CancelIngestionResponseTypeDef,
    CastColumnTypeOperationTypeDef,
    ColumnDescriptionTypeDef,
    ColumnGroupColumnSchemaTypeDef,
    ColumnGroupSchemaTypeDef,
    ColumnGroupTypeDef,
    ColumnLevelPermissionRuleTypeDef,
    ColumnSchemaTypeDef,
    ColumnTagTypeDef,
    CreateAccountCustomizationResponseTypeDef,
    CreateAnalysisResponseTypeDef,
    CreateColumnsOperationTypeDef,
    CreateDashboardResponseTypeDef,
    CreateDataSetResponseTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateGroupMembershipResponseTypeDef,
    CreateGroupResponseTypeDef,
    CreateIAMPolicyAssignmentResponseTypeDef,
    CreateIngestionResponseTypeDef,
    CreateNamespaceResponseTypeDef,
    CreateTemplateAliasResponseTypeDef,
    CreateTemplateResponseTypeDef,
    CreateThemeAliasResponseTypeDef,
    CreateThemeResponseTypeDef,
    CredentialPairTypeDef,
    CustomSqlTypeDef,
    DashboardErrorTypeDef,
    DashboardPublishOptionsTypeDef,
    DashboardSearchFilterTypeDef,
    DashboardSourceEntityTypeDef,
    DashboardSourceTemplateTypeDef,
    DashboardSummaryTypeDef,
    DashboardTypeDef,
    DashboardVersionSummaryTypeDef,
    DashboardVersionTypeDef,
    DataColorPaletteTypeDef,
    DataSetConfigurationTypeDef,
    DataSetReferenceTypeDef,
    DataSetSchemaTypeDef,
    DataSetSummaryTypeDef,
    DataSetTypeDef,
    DataSourceCredentialsTypeDef,
    DataSourceErrorInfoTypeDef,
    DataSourceParametersTypeDef,
    DataSourceTypeDef,
    DateTimeParameterTypeDef,
    DecimalParameterTypeDef,
    DeleteAccountCustomizationResponseTypeDef,
    DeleteAnalysisResponseTypeDef,
    DeleteDashboardResponseTypeDef,
    DeleteDataSetResponseTypeDef,
    DeleteDataSourceResponseTypeDef,
    DeleteGroupMembershipResponseTypeDef,
    DeleteGroupResponseTypeDef,
    DeleteIAMPolicyAssignmentResponseTypeDef,
    DeleteNamespaceResponseTypeDef,
    DeleteTemplateAliasResponseTypeDef,
    DeleteTemplateResponseTypeDef,
    DeleteThemeAliasResponseTypeDef,
    DeleteThemeResponseTypeDef,
    DeleteUserByPrincipalIdResponseTypeDef,
    DeleteUserResponseTypeDef,
    DescribeAccountCustomizationResponseTypeDef,
    DescribeAccountSettingsResponseTypeDef,
    DescribeAnalysisPermissionsResponseTypeDef,
    DescribeAnalysisResponseTypeDef,
    DescribeDashboardPermissionsResponseTypeDef,
    DescribeDashboardResponseTypeDef,
    DescribeDataSetPermissionsResponseTypeDef,
    DescribeDataSetResponseTypeDef,
    DescribeDataSourcePermissionsResponseTypeDef,
    DescribeDataSourceResponseTypeDef,
    DescribeGroupResponseTypeDef,
    DescribeIAMPolicyAssignmentResponseTypeDef,
    DescribeIngestionResponseTypeDef,
    DescribeNamespaceResponseTypeDef,
    DescribeTemplateAliasResponseTypeDef,
    DescribeTemplatePermissionsResponseTypeDef,
    DescribeTemplateResponseTypeDef,
    DescribeThemeAliasResponseTypeDef,
    DescribeThemePermissionsResponseTypeDef,
    DescribeThemeResponseTypeDef,
    DescribeUserResponseTypeDef,
    ErrorInfoTypeDef,
    ExportToCSVOptionTypeDef,
    FieldFolderTypeDef,
    FilterOperationTypeDef,
    GeoSpatialColumnGroupTypeDef,
    GetDashboardEmbedUrlResponseTypeDef,
    GetSessionEmbedUrlResponseTypeDef,
    GroupMemberTypeDef,
    GroupTypeDef,
    GutterStyleTypeDef,
    IAMPolicyAssignmentSummaryTypeDef,
    IAMPolicyAssignmentTypeDef,
    IngestionTypeDef,
    InputColumnTypeDef,
    IntegerParameterTypeDef,
    JiraParametersTypeDef,
    JoinInstructionTypeDef,
    JoinKeyPropertiesTypeDef,
    ListAnalysesResponseTypeDef,
    ListDashboardVersionsResponseTypeDef,
    ListDashboardsResponseTypeDef,
    ListDataSetsResponseTypeDef,
    ListDataSourcesResponseTypeDef,
    ListGroupMembershipsResponseTypeDef,
    ListGroupsResponseTypeDef,
    ListIAMPolicyAssignmentsForUserResponseTypeDef,
    ListIAMPolicyAssignmentsResponseTypeDef,
    ListIngestionsResponseTypeDef,
    ListNamespacesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTemplateAliasesResponseTypeDef,
    ListTemplateVersionsResponseTypeDef,
    ListTemplatesResponseTypeDef,
    ListThemeAliasesResponseTypeDef,
    ListThemeVersionsResponseTypeDef,
    ListThemesResponseTypeDef,
    ListUserGroupsResponseTypeDef,
    ListUsersResponseTypeDef,
    LogicalTableSourceTypeDef,
    LogicalTableTypeDef,
    ManifestFileLocationTypeDef,
    MarginStyleTypeDef,
    MariaDbParametersTypeDef,
    MySqlParametersTypeDef,
    NamespaceErrorTypeDef,
    NamespaceInfoV2TypeDef,
    OracleParametersTypeDef,
    OutputColumnTypeDef,
    PaginatorConfigTypeDef,
    ParametersTypeDef,
    PhysicalTableTypeDef,
    PostgreSqlParametersTypeDef,
    PrestoParametersTypeDef,
    ProjectOperationTypeDef,
    QueueInfoTypeDef,
    RdsParametersTypeDef,
    RedshiftParametersTypeDef,
    RegisterUserResponseTypeDef,
    RelationalTableTypeDef,
    RenameColumnOperationTypeDef,
    ResourcePermissionTypeDef,
    RestoreAnalysisResponseTypeDef,
    RowInfoTypeDef,
    RowLevelPermissionDataSetTypeDef,
    S3ParametersTypeDef,
    S3SourceTypeDef,
    SearchAnalysesResponseTypeDef,
    SearchDashboardsResponseTypeDef,
    ServiceNowParametersTypeDef,
    SheetControlsOptionTypeDef,
    SheetStyleTypeDef,
    SheetTypeDef,
    SnowflakeParametersTypeDef,
    SparkParametersTypeDef,
    SqlServerParametersTypeDef,
    SslPropertiesTypeDef,
    StringParameterTypeDef,
    TagColumnOperationTypeDef,
    TagResourceResponseTypeDef,
    TagTypeDef,
    TemplateAliasTypeDef,
    TemplateErrorTypeDef,
    TemplateSourceAnalysisTypeDef,
    TemplateSourceEntityTypeDef,
    TemplateSourceTemplateTypeDef,
    TemplateSummaryTypeDef,
    TemplateTypeDef,
    TemplateVersionSummaryTypeDef,
    TemplateVersionTypeDef,
    TeradataParametersTypeDef,
    ThemeAliasTypeDef,
    ThemeConfigurationTypeDef,
    ThemeErrorTypeDef,
    ThemeSummaryTypeDef,
    ThemeTypeDef,
    ThemeVersionSummaryTypeDef,
    ThemeVersionTypeDef,
    TileLayoutStyleTypeDef,
    TileStyleTypeDef,
    TransformOperationTypeDef,
    TwitterParametersTypeDef,
    UIColorPaletteTypeDef,
    UntagResourceResponseTypeDef,
    UpdateAccountCustomizationResponseTypeDef,
    UpdateAccountSettingsResponseTypeDef,
    UpdateAnalysisPermissionsResponseTypeDef,
    UpdateAnalysisResponseTypeDef,
    UpdateDashboardPermissionsResponseTypeDef,
    UpdateDashboardPublishedVersionResponseTypeDef,
    UpdateDashboardResponseTypeDef,
    UpdateDataSetPermissionsResponseTypeDef,
    UpdateDataSetResponseTypeDef,
    UpdateDataSourcePermissionsResponseTypeDef,
    UpdateDataSourceResponseTypeDef,
    UpdateGroupResponseTypeDef,
    UpdateIAMPolicyAssignmentResponseTypeDef,
    UpdateTemplateAliasResponseTypeDef,
    UpdateTemplatePermissionsResponseTypeDef,
    UpdateTemplateResponseTypeDef,
    UpdateThemeAliasResponseTypeDef,
    UpdateThemePermissionsResponseTypeDef,
    UpdateThemeResponseTypeDef,
    UpdateUserResponseTypeDef,
    UploadSettingsTypeDef,
    UserTypeDef,
    VpcConnectionPropertiesTypeDef,
)

def get_structure() -> AccountCustomizationTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-quicksight` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-quicksight docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
